pmean: Centering on person-means

View source: R/pmean.R

pmeanR Documentation

Centering on person-means

Description

This function allows you calculate person-level means. This will create a level-2 variable that can be used in tandem with person-centered means. This is useful if you are interested in both the within-person and between-person effects.

Usage

pmean(ID, var)

Arguments

ID

name of ID variable

var

name of variable to be centered

Value

A column in your dataframe (with person-level means)

Examples

df <- data.frame(ID = c(1, 1, 2, 2), var = c(1, 3, 5, 9))
df$personMEAN <- pmean(df$ID, df$var)

EMAtools documentation built on June 22, 2026, 5:08 p.m.